@@ -2,12 +2,10 @@
 
 __author__ = "eseunghwan"
 __email__ = "shlee0920@naver.com"
-__version__ = "0.5.1"
+__version__ = "0.5.2"
 
 from .core._vue import VueUtils as Vue
-from .webview import WebViewUtils as Webview
-from .core.server import Server
 
 __all__ = [
-    "Vue", "Webview", "Server"
+    "Vue"
 ]
