@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import sys
 from collections import OrderedDict
-from PySide2.QtWidgets import QApplication, QMainWindow, QDialog, QGridLayout
+from PySide2.QtWidgets import QApplication, QMainWindow, QDialog, QGridLayout, QMessageBox
 from PySide2.QtWebEngineWidgets import QWebEngineView, QWebEnginePage
 from PySide2.QtCore import QUrl, Signal
 from PySide2.QtGui import QIcon
@@ -12,7 +12,7 @@ windows = OrderedDict()
 dialogs = OrderedDict()
 current_window = None
 current_dialog = None
-
+current_msgbox = None
 
 class WebDialog(QDialog):
     def __init__(self, title:str, url:str, name:str = None, x:int = None, y:int = None, width:int = None, height:int = None, parent = None):
@@ -61,11 +61,13 @@ class WebDialog(QDialog):
 class Webwindow(QMainWindow):
     create_window = Signal(object, str, str, str, int, int, int, int)
     create_dialog = Signal(object, str, str, str, int, int, int, int, QMainWindow)
+    show_messagebox = Signal(str, str, str, object)
 
     def __init__(self, title:str, url:str, name:str = None, x:int = None, y:int = None, width:int = None, height:int = None):
         super().__init__(None)
         self.create_window.connect(self.__on_create_window)
         self.create_dialog.connect(self.__on_create_dialog)
+        self.show_messagebox.connect(self.__on_show_messagebox)
 
         global qtApp, windows
         if name in ("", None):
@@ -104,18 +106,33 @@ class Webwindow(QMainWindow):
     def __onload(self, ev):
         self.showNormal()
 
-    def __on_create_window(self, func, title:str, name:str, url:str, x:int, y:int, width:int, height:int) -> QMainWindow:
+    def __on_create_window(self, func, title:str, name:str, url:str, x:int, y:int, width:int, height:int):
         global windows, current_window
 
         current_window = func(title, url, name, x, y, width, height)
         windows[current_window.name] = current_window
 
-    def __on_create_dialog(self, func, title:str, url:str, name:str, x:int, y:int, width:int, height:int, parent) -> WebDialog:
+    def __on_create_dialog(self, func, title:str, url:str, name:str, x:int, y:int, width:int, height:int, parent):
         global dialogs, current_dialog
 
         current_dialog = func(title, url, name, x, y, width, height, self if parent == None else parent)
         dialogs[current_dialog.name] = current_dialog
 
+    def __on_show_messagebox(self, title:str, content:str, messagebox_type:str, parent:object):
+        if parent == None:
+            parent = self
+
+        try:
+            msg_icon = eval(f"QMessageBox.Icon.{messagebox_type.capitalize()}")
+        except AttributeError:
+            msg_icon = QMessageBox.Icon.Information
+
+        msgbox = QMessageBox(parent)
+        msgbox.setIcon(msg_icon)
+        msgbox.setWindowTitle(title)
+        msgbox.setText(content)
+        msgbox.exec_()
+
 class WebViewUtils():
     @staticmethod
     def create_window(title:str, url:str, name:str = None, x:int = None, y:int = None, width:int = None, height:int = None):
@@ -160,6 +177,11 @@ class WebViewUtils():
                 return current_dialog
 
     @staticmethod
-    def start(app_icon:str):
-        qtApp.setWindowIcon(QIcon(app_icon))
-        qtApp.exec_()
\ No newline at end of file
+    def show_messagebox(title:str, content:str, messagebox_type:str = "information", parent = None):
+        global windows, current_msgbox
+
+        return windows["main"].show_messagebox.emit(title, content, messagebox_type, parent)
+
+def start(app_icon:str):
+    qtApp.setWindowIcon(QIcon(app_icon))
+    qtApp.exec_()
\ No newline at end of file
